MacroString

Struct MacroString 

pub struct MacroString { /* private fields */ }

Implementations

Source

impl MacroString

pub fn eval(&self) -> Result<String>

Evaluate expression to string.

Errors

Returns an error if the expression was syntactically valid (parsed successfully) but cannot be evaluated, for example because it refers to an env! for which the environment variable is not set, or an include! for which the file is not found.

pub fn error<T: Display>(&self, message: T) -> Error

Construct a compile error with a Span encompassing the macro string’s original expression.

my_macro! {
    resources = concat!(env!("CARGO_MANIFEST_DIR"), "/resources.json")
}
error: No such file or directory (os error 2) - /path/to/manifest-dir/resources.json
  --> example.rs:85:17
   |
85 |     resources = concat!(env!("CARGO_MANIFEST_DIR"), "/resources.json")
   |                 ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^